# rLink Python Library

Python library for controlling Hobby Components rLink RS485 modules using a Raspberry Pi.

Currently supported modules:
- Hobby Components RS485 transceiver (HCMODU0270)
- rLink 2-Channel Relay Module (HCMODU0281)

This library communicates over RS485 via the Raspberry Pi UART and GPIO.
You will also need a serial-to-RS485 transceiver (see above).

Please see the rLink section of our support forum for examples of how
to use this module with specific rLink devices:

https://hobbycomponents.com/rlink
